from typing import List

from bluer_options.terminal import show_usage, xtra

from bluer_journal.help.git import push_options


def help_add(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "".join(
        [
            xtra("~pull,", mono=mono),
            "todo",
        ]
    )

    args = [
        "[--title <YYYY-MM-DD>]",
        "[--verbose 1]",
    ]

    return show_usage(
        [
            "@journal",
            "add",
            f"[{options}]",
            "<message>",
            f"[{push_options(mono=mono)}]",
        ]
        + args,
        "add to journal.",
        mono=mono,
    )



from blueness import module

from bluer_journal import NAME
from bluer_journal.classes.page import JournalPage
from bluer_journal.logger import logger


NAME = module.name(__file__, NAME)


def add_message(
    message: str,
    title: str,
    todo: bool = False,
    verbose: bool = False,
) -> bool:
    logger.info(
        "{}.add_message({}{}) -> {}".format(
            NAME,
            "✔️" if todo else "",
            message,
            title,
        )
    )

    page = JournalPage(
        title=title,
        verbose=verbose,
    )

    page.content += [
        "",
        f" - [ ] {message}" if todo else message,
    ]

    return page.save(
        verbose=verbose,
    )



import re
import calendar

from blueness import module

from bluer_journal import NAME
from bluer_journal.classes.page import JournalPage
from bluer_journal.logger import logger


NAME = module.name(__file__, NAME)


def sync_calendar(
    title: str,
    verbose: bool = False,
) -> bool:
    if bool(re.fullmatch(r"\d{4}-\d{2}-\d{2}", title)):
        return True

    logger.info(f"{NAME}.sync_calendar({title})")

    title_pieces = [int(piece) for piece in title.split("-")]
    year = title_pieces[0]
    month = title_pieces[0]

    if verbose:
        logger.info(f"+= {year}...")
    year_page = JournalPage(
        title=str(year),
        verbose=verbose,
    )
    for month in range(1, 13):
        if verbose:
            logger.info(f"+= {year}-{month:02d}...")
        message_ = f"- [[{year}-{month:02d}]]"
        if message_ not in year_page.content:
            year_page.content += [message_]

        month_page = JournalPage(
            title=f"{year}-{month:02d}",
            verbose=verbose,
        )
        _, last_day = calendar.monthrange(year, month)
        for day in range(1, last_day + 1):
            message_ = f"- [[{year}-{month:02d}-{day:02d}]]"
            if message_ not in month_page.content:
                month_page.content += [message_]
        if not month_page.save(verbose=verbose):
            return False

    return year_page.save(verbose=verbose)



import argparse

from blueness import module
from blueness.argparse.generic import sys_exit
from bluer_options import string

from bluer_journal import NAME
from bluer_journal.utils.add import add_message
from bluer_journal.logger import logger

NAME = module.name(__file__, NAME)

parser = argparse.ArgumentParser(NAME)
parser.add_argument(
    "task",
    type=str,
    help="add | sync",
)
parser.add_argument(
    "--message",
    type=str,
)
parser.add_argument(
    "--title",
    type=str,
    default="",
)
parser.add_argument(
    "--todo",
    type=int,
    default=0,
    help="0 |1",
)
parser.add_argument(
    "--verbose",
    type=int,
    default=0,
    help="0 |1",
)
args = parser.parse_args()

success = False
if args.task == "add":
    success = add_message(
        message=args.message,
        title=(
            args.title
            if args.title
            else string.pretty_date(
                include_time=False,
                as_filename=True,
            )
        ),
        todo=args.todo,
        verbose=args.verbose == 1,
    )
elif args.task == "sync":
    success = True
    logger.info("🪄")
else:
    success = None

sys_exit(logger, NAME, args.task, success)



import os

from bluer_objects import file
from bluer_objects.env import abcli_path_git

from bluer_journal.env import BLUER_JOURNAL_REPO
from bluer_journal.logger import logger


class JournalPage:
    def __init__(
        self,
        title: str,
        verbose: bool = False,
    ):
        assert title

        self.title = title
        self.load(verbose)

    @property
    def filename(self) -> str:
        return os.path.join(
            abcli_path_git,
            f"{BLUER_JOURNAL_REPO}.wiki",
            f"{self.title}.md",
        )

    def load(
        self,
        verbose: bool = False,
    ):
        _, self.content = file.load_text(
            self.filename,
            ignore_error=True,
            log=verbose,
        )

    def save(
        self,
        verbose: bool = False,
    ) -> bool:
        return file.save_text(
            self.filename,
            self.content,
            log=verbose,
        )



from typing import List

from bluer_options.terminal import show_usage, xtra
from bluer_ai.help.generic import help_functions as generic_help_functions

from bluer_journal import ALIAS
from bluer_journal.help.add import help_add
from bluer_journal.help.git import help_functions as help_git
from bluer_journal.help.open import help_open

help_functions = generic_help_functions(plugin_name=ALIAS)

help_functions.update(
    {
        "add": help_add,
        "git": help_git,
        "open": help_open,
    }
)
